@@ -12,4 +12,5 @@ try:
     pkg_resources.declare_namespace(__name__)
 except ImportError:
     import pkgutil
-    __path__ = pkgutil.extend_path(__path__, __name__)  # type: ignore[has-type]
+    __path__ = pkgutil.extend_path(
+        __path__, __name__)  # type: ignore[has-type]
