@@ -80,7 +80,6 @@ class BaseSession(object):
 if not BUILD_GCLOUD_REST:
     import aiohttp
 
-
     def _raise_for_status(resp                        )        :
         """Check resp for status and if error log additional info."""
         # Copied from aiohttp's raise_for_status() -- since it releases the
@@ -130,8 +129,8 @@ if not BUILD_GCLOUD_REST:
                       timeout      = 10,
                       params                           = None
                       )                          :
-            resp = self.session.get(url, headers=headers, timeout=timeout,
-                                          params=params)
+            resp = self.session.get(url, headers=headers,
+                                          timeout=timeout, params=params)
             _raise_for_status(resp)
             return resp
 
